==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/type/v1beta1/WorkloadSelectorFluent.java <==
package io.fabric8.istio.api.type.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class WorkloadSelectorFluent<A extends WorkloadSelectorFluent<A>> extends BaseFluent<A>{
  public WorkloadSelectorFluent() {
  }
  public WorkloadSelectorFluent(WorkloadSelector instance) {
    instance = (instance != null ? instance : new WorkloadSelector());

    if (instance != null) {
      this.withMatchLabels(instance.getMatchLabels());
      this.withMatchLabels(instance.getMatchLabels());
    }
  }
  private Map<String,String> matchLabels;
  public A addToMatchLabels(String key,String value) {
    if(this.matchLabels == null && key != null && value != null) { this.matchLabels = new LinkedHashMap(); }
    if(key != null && value != null) {this.matchLabels.put(key, value);} return (A)this;
  }
  public A addToMatchLabels(Map<String,String> map) {
    if(this.matchLabels == null && map != null) { this.matchLabels = new LinkedHashMap(); }
    if(map != null) { this.matchLabels.putAll(map);} return (A)this;
  }
  public A removeFromMatchLabels(String key) {
    if(this.matchLabels == null) { return (A) this; }
    if(key != null && this.matchLabels != null) {this.matchLabels.remove(key);} return (A)this;
  }
  public A removeFromMatchLabels(Map<String,String> map) {
    if(this.matchLabels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.matchLabels != null){this.matchLabels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getMatchLabels() {
    return this.matchLabels;
  }
  public <K,V>A withMatchLabels(Map<String,String> matchLabels) {
    if (matchLabels == null) { this.matchLabels =  null;} else {this.matchLabels = new LinkedHashMap(matchLabels);} return (A) this;
  }
  public boolean hasMatchLabels() {
    return this.matchLabels != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadSelectorFluent that = (WorkloadSelectorFluent) o;
    if (!java.util.Objects.equals(matchLabels, that.matchLabels)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(matchLabels,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchLabels != null && !matchLabels.isEmpty()) { sb.append("matchLabels:"); sb.append(matchLabels); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/type/v1beta1/WorkloadSelectorFluent.java <==
package io.fabric8.istio.api.type.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class WorkloadSelectorFluent<A extends WorkloadSelectorFluent<A>> extends BaseFluent<A>{
  public WorkloadSelectorFluent() {
  }
  
  public WorkloadSelectorFluent(WorkloadSelector instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> matchLabels;
  
  protected void copyInstance(WorkloadSelector instance) {
    instance = (instance != null ? instance : new WorkloadSelector());
  
    if (instance != null) {
        this.withMatchLabels(instance.getMatchLabels());
        this.withMatchLabels(instance.getMatchLabels());
      }
  }
  
  public A addToMatchLabels(String key,String value) {
    if(this.matchLabels == null && key != null && value != null) { this.matchLabels = new LinkedHashMap(); }
    if(key != null && value != null) {this.matchLabels.put(key, value);} return (A)this;
  }
  
  public A addToMatchLabels(Map<String,String> map) {
    if(this.matchLabels == null && map != null) { this.matchLabels = new LinkedHashMap(); }
    if(map != null) { this.matchLabels.putAll(map);} return (A)this;
  }
  
  public A removeFromMatchLabels(String key) {
    if(this.matchLabels == null) { return (A) this; }
    if(key != null && this.matchLabels != null) {this.matchLabels.remove(key);} return (A)this;
  }
  
  public A removeFromMatchLabels(Map<String,String> map) {
    if(this.matchLabels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.matchLabels != null){this.matchLabels.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getMatchLabels() {
    return this.matchLabels;
  }
  
  public <K,V>A withMatchLabels(Map<String,String> matchLabels) {
    if (matchLabels == null) { this.matchLabels =  null;} else {this.matchLabels = new LinkedHashMap(matchLabels);} return (A) this;
  }
  
  public boolean hasMatchLabels() {
    return this.matchLabels != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WorkloadSelectorFluent that = (WorkloadSelectorFluent) o;
    if (!java.util.Objects.equals(matchLabels, that.matchLabels)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(matchLabels,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (matchLabels != null && !matchLabels.isEmpty()) { sb.append("matchLabels:"); sb.append(matchLabels); }
    sb.append("}");
    return sb.toString();
  }
  

}
